@@ -18,7 +18,7 @@ class DescriptionParser(nodes.NodeVisitor):
 
         # Hack to prevent requirement for the doctree to be passed in.
         # It's only used by doctree.walk(...) to print debug messages.
-        if document == None:
+        if document is None:
 
             class document_cls:
                 class reporter:
@@ -124,5 +124,4 @@ def get_description(
 
     mcv = DescriptionParser(description_length, known_titles, document)
     doctree.walkabout(mcv)
-    # Parse quotation so they won't break html tags if smart quotes are disabled
-    return mcv.description.replace('"', "&quot;")
+    return mcv.description
